@@ -11,7 +11,6 @@ use crate::types::expression::convert_type;
 use crate::types::{array_length_bits, PrimitiveType, ResolvedType};
 use canadensis_bit_length_set::BitLengthSet;
 use canadensis_dsdl_parser::{Identifier, Span, Statement};
-use itertools::Itertools;
 use once_cell::sync::Lazy;
 use std::collections::btree_map::Entry;
 use std::collections::BTreeMap;
@@ -60,7 +59,7 @@ impl<'p> CompileContext<'p> {
 
     /// Returns a bit length set covering the fields that have been processed so far
     ///
-    /// This is useful for the _offset_ magic variable.
+    /// This is useful for the `_offset_` magic variable.
     pub fn bit_length_set(&mut self) -> &BitLengthSet {
         // If necessary, change the state to calculate the union bit length
         match self.current_file.state.take().expect("No state") {
@@ -829,7 +828,7 @@ fn make_union_bit_length(variants: &[Variant]) -> BitLengthSet {
     let variant_lengths = variants
         .iter()
         .map(|variant| variant.ty.size())
-        .fold1(|size1, size2| size1.unite([size2]))
+        .reduce(|size1, size2| size1.unite([size2]))
         .unwrap_or_else(|| BitLengthSet::single(0));
     // Concatenate the discriminant and the variant lengths
     discriminant_length.concatenate([variant_lengths])
